PyTimings
=========

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/renefritze/pytimings/main.svg)](https://results.pre-commit.ci/latest/github/renefritze/pytimings/main)
[![image](https://img.shields.io/pypi/v/pytimings.svg)](https://pypi.python.org/pypi/pytimings)
[![Documentation Status](https://readthedocs.org/projects/pytimings/badge/?version=latest)](https://pytimings.readthedocs.io/en/latest/?badge=latest)



Section timings

-   Free software: BSD license
-   Documentation: <https://pytimings.readthedocs.io>.
-   [![Live examples](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/renefritze/pytimings/HEAD?filepath=docs%2Fexamples%2F)


Features
--------

- Automatic, decorator-based code timings
- manual control
- structured (CSV/terminal) output
- matplotlib plotting of results


Usage
-----

See [this section](https://pytimings.readthedocs.io/en/latest/usage.html) in our documentation

Credits
-------

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.
